/*
** Module   : ImageWidgetSupport.java
** Abstract : Defines image specific widget-related APIs available via a widget handle instance.
**
** Copyright (c) 2015, Golden Code Development Corporation.
** ALL RIGHTS RESERVED. Use is subject to license terms.
**
**           Golden Code Development Corporation
**                      CONFIDENTIAL
**
** -#- -I- --Date-- ---------------------------------Description---------------------------------
** 001 EVL 20150223 Created initial version.
*/

package com.goldencode.p2j.ui;

import com.goldencode.p2j.util.*;

/**
 * Provide access to image widget specific attributes APIs which can be accessed via handle
 * instance.
 */
public interface ImageWidgetSupport
extends ImageSupport
{
   /**
    * Gets TRANSPARENT attribute.
    * 
    * @return  TRANSPARENT current value.
    */
   @LegacyAttribute(name = "TRANSPARENT")
   public logical getTransparent();

   /**
    * Set TRANSPARENT attribute.
    * 
    * @param   flag
    *          New value for the attribute.
    */
   @LegacyAttribute(name = "TRANSPARENT", setter = true)
   public void setTransparent(boolean flag);

   /**
    * Set TRANSPARENT attribute.
    * 
    * @param   flag
    *          New value for the attribute.
    */
   @LegacyAttribute(name = "TRANSPARENT", setter = true)
   public void setTransparent(logical flag);

   /**
    * Gets STRETCH-TO-FIT attribute.
    * 
    * @return  STRETCH-TO-FIT current value.
    */
   @LegacyAttribute(name = "STRETCH-TO-FIT")
   public logical getStretchToFit();

   /**
    * Set STRETCH-TO-FIT attribute.
    * 
    * @param   flag
    *          New value for the attribute.
    */
   @LegacyAttribute(name = "STRETCH-TO-FIT", setter = true)
   public void setStretchToFit(boolean flag);

   /**
    * Set STRETCH-TO-FIT attribute.
    * 
    * @param   flag
    *          New value for the attribute.
    */
   @LegacyAttribute(name = "STRETCH-TO-FIT", setter = true)
   public void setStretchToFit(logical flag);

   /**
    * Gets RETAIN-SHAPE attribute.
    * 
    * @return  RETAIN-SHAPE current value.
    */
   @LegacyAttribute(name = "RETAIN-SHAPE")
   public logical getRetainShape();

   /**
    * Set RETAIN-SHAPE attribute.
    * 
    * @param   flag
    *          New value for the attribute.
    */
   @LegacyAttribute(name = "RETAIN-SHAPE", setter = true)
   public void setRetainShape(boolean flag);

   /**
    * Set RETAIN-SHAPE attribute.
    * 
    * @param   flag
    *          New value for the attribute.
    */
   @LegacyAttribute(name = "RETAIN-SHAPE", setter = true)
   public void setRetainShape(logical flag);
}
